@@ -18,12 +18,7 @@ import urllib.parse
 
 import tornado.web
 from bson import ObjectId
-from utils import awaitable
-from utils import cached_property
-from utils import Dict
-from utils import JSONEncoder
-from utils import Mongo
-from utils import Motor
+from utils import Dict, JSONEncoder, Mongo, Motor, awaitable, cached_property
 
 
 class BaseHandler(tornado.web.RequestHandler):
